Voikko
======

This package contains Python bindings for libvoikko and the inflection module + word data.
The inflection module has been translated to Python 3, but is otherwise original.

Please see https://github.com/voikko/corevoikko/ for the original versions created by Harri Pitkänen.
